package com.yanzhu.manage.mapper;

import java.util.List;
import java.util.Map;

import com.yanzhu.manage.domain.BusTrainingVideo;

/**
 * 培训视频Mapper接口
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
public interface BusTrainingVideoMapper 
{
    /**
     * 查询培训视频
     * 
     * @param id 培训视频主键
     * @return 培训视频
     */
    public BusTrainingVideo selectBusTrainingVideoById(Long id);

    /**
     * 查询培训视频列表
     * 
     * @param busTrainingVideo 培训视频
     * @return 培训视频集合
     */
    public List<BusTrainingVideo> selectBusTrainingVideoList(BusTrainingVideo busTrainingVideo);

    /**
     * 统计培训视频列表
     *
     * @param busTrainingVideo 培训视频
     * @return 培训视频集合
     */
    public List<Map<String, Object>> findBusTrainingVideoByLevel(BusTrainingVideo busTrainingVideo);

    /**
     * 新增培训视频
     * 
     * @param busTrainingVideo 培训视频
     * @return 结果
     */
    public int insertBusTrainingVideo(BusTrainingVideo busTrainingVideo);

    /**
     * 修改培训视频
     * 
     * @param busTrainingVideo 培训视频
     * @return 结果
     */
    public int updateBusTrainingVideo(BusTrainingVideo busTrainingVideo);

    /**
     * 删除培训视频
     * 
     * @param id 培训视频主键
     * @return 结果
     */
    public int deleteBusTrainingVideoById(Long id);

    /**
     * 批量删除培训视频
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusTrainingVideoByIds(Long[] ids);
}
